@@ -27,6 +27,7 @@ class SubprocessFilter(Filter):
             'initial-timeout' : ('', 10),
             'scriptargs' : ("Arguments to be passed to the executable.", ''),
             'timeout' : ('', 10),
+            'use-wd' : ("Whether to use a custom working directory when running filter.", True),
             'version-command': ( "Command to call to return version of installed software.", None),
             'windows-version-command': ( "Command to call on windows to return version of installed software.", None),
             'walk-working-dir' : ("Automatically register extra files that are found in working dir.", False),
@@ -88,8 +89,11 @@ class SubprocessFilter(Filter):
         self.output_data.clear_cache()
 
     def handle_subprocess_proc_return(self, command, exitcode, stderr):
+        self.log_debug("exit code is '%s'" % exitcode)
         if exitcode is None:
             raise dexy.exceptions.InternalDexyProblem("no return code, proc not finished!")
+        elif exitcode == 127:
+            raise dexy.exceptions.InactiveFilter(self)
         elif exitcode != 0 and self.setting('check-return-code'):
             if self.ignore_nonzero_exit():
                 self.log_warn("Nonzero exit status %s" % exitcode)
@@ -112,6 +116,8 @@ class SubprocessFilter(Filter):
 
         env.update(self.setting('env'))
 
+        env['DEXY_ROOT'] = os.path.abspath(".")
+
         # Add parameters in wrapper's env dict
         if self.is_part_of_script_bundle():
             for key, value in self.script_storage().iteritems():
@@ -214,6 +220,7 @@ class SubprocessFilter(Filter):
             doc = self.add_doc(doc_key, {})
 
         doc.output_data().setup()
+        doc.output_data().storage.connect()
         wd = self.workspace()
 
         for dirpath, dirnames, filenames in os.walk(wd):
@@ -232,11 +239,12 @@ class SubprocessFilter(Filter):
         return doc
 
     def run_command(self, command, env, input_text=None):
-        ws = self.workspace()
-        if os.path.exists(ws):
-            self.log_debug("already have workspace '%s'" % os.path.abspath(ws))
-        else:
-            self.populate_workspace()
+        if self.setting('use-wd'):
+            ws = self.workspace()
+            if os.path.exists(ws):
+                self.log_debug("already have workspace '%s'" % os.path.abspath(ws))
+            else:
+                self.populate_workspace()
 
         stdout = subprocess.PIPE
 
@@ -250,7 +258,11 @@ class SubprocessFilter(Filter):
         else:
             stderr = subprocess.PIPE
 
-        wd = self.parent_work_dir()
+        if self.setting('use-wd'):
+            wd = self.parent_work_dir()
+        else:
+            wd = os.getcwd()
+
         self.log_debug("about to run '%s' in '%s'" % (command, os.path.abspath(wd)))
         proc = subprocess.Popen(command, shell=True,
                                     cwd=wd,
@@ -341,8 +353,7 @@ class SubprocessCompileFilter(SubprocessFilter):
         proc, stdout = self.run_command(command, env)
 
         # This tests exitcode from the compiled script.
-        if self.setting('check-return-code'):
-            self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+        self.handle_subprocess_proc_return(command, proc.returncode, stdout)
 
         self.output_data.set_data(stdout)
 
@@ -373,14 +384,12 @@ class SubprocessInputFilter(SubprocessFilter):
             doc = inputs[0]
             for section_name, section_text in doc.output_data().as_sectioned().iteritems():
                 proc, stdout = self.run_command(command, self.setup_env(), section_text)
-                if self.setting('check-return-code'):
-                    self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+                self.handle_subprocess_proc_return(command, proc.returncode, stdout)
                 output[section_name] = stdout
         else:
             for doc in inputs:
                 proc, stdout = self.run_command(command, self.setup_env(), unicode(doc.output_data()))
-                if self.setting('check-return-code'):
-                    self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+                self.handle_subprocess_proc_return(command, proc.returncode, stdout)
                 output[doc.key] = stdout
 
         self.output_data.set_data(output)
@@ -411,8 +420,7 @@ class SubprocessInputFileFilter(SubprocessFilter):
         for doc in self.doc.walk_input_docs():
             command = self.command_string_for_input(doc)
             proc, stdout = self.run_command(command, self.setup_env())
-            if self.setting('check-return-code'):
-                self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+            self.handle_subprocess_proc_return(command, proc.returncode, stdout)
             output[doc.key] = stdout
 
         self.output_data.set_data(output)
@@ -443,14 +451,12 @@ class SubprocessCompileInputFilter(SubprocessCompileFilter):
             doc = inputs[0]
             for section_name, section_text in doc.output_data().as_sectioned().iteritems():
                 proc, stdout = self.run_command(command, self.setup_env(), section_text)
-                if self.setting('check-return-code'):
-                    self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+                self.handle_subprocess_proc_return(command, proc.returncode, stdout)
                 output[section_name] = stdout
         else:
             for doc in inputs:
                 proc, stdout = self.run_command(command, self.setup_env(), doc.output_data().as_text())
-                if self.setting('check-return-code'):
-                    self.handle_subprocess_proc_return(command, proc.returncode, stdout)
+                self.handle_subprocess_proc_return(command, proc.returncode, stdout)
                 output[doc.key] = stdout
 
         self.output_data.set_data(output)
